0.9.9 API documentation: scalar_common.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

scalar_common.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../common.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # pragma message("GLM: GLM_EXT_scalar_common extension included")
21 #endif
22
23 namespace glm
24 {
27
31 template<typename T>
32 GLM_FUNC_DECL T min(T a, T b, T c);
33
37 template<typename T>
38 GLM_FUNC_DECL T min(T a, T b, T c, T d);
39
43 template<typename T>
44 GLM_FUNC_DECL T max(T a, T b, T c);
45
49 template<typename T>
50 GLM_FUNC_DECL T max(T a, T b, T c, T d);
51
57 template<typename T>
58 GLM_FUNC_DECL T fmin(T a, T b);
59
65 template<typename T>
66 GLM_FUNC_DECL T fmin(T a, T b, T c);
67
73 template<typename T>
74 GLM_FUNC_DECL T fmin(T a, T b, T c, T d);
75
81 template<typename T>
82 GLM_FUNC_DECL T fmax(T a, T b);
83
89 template<typename T>
90 GLM_FUNC_DECL T fmax(T a, T b, T C);
91
97 template<typename T>
98 GLM_FUNC_DECL T fmax(T a, T b, T C, T D);
99
101 }//namespace glm
102
103 #include "scalar_common.inl"
glm::min
GLM_FUNC_DECL T min(T a, T b, T c, T d)
Returns the minimum component-wise values of 4 inputs.
glm::max
GLM_FUNC_DECL T max(T a, T b, T c, T d)
Returns the maximum component-wise values of 4 inputs.
glm::fmax
GLM_FUNC_DECL T fmax(T a, T b, T C, T D)
Returns the maximum component-wise values of 4 inputs.
glm::fmin
GLM_FUNC_DECL T fmin(T a, T b, T c, T d)
Returns the minimum component-wise values of 4 inputs.
glm
Definition: common.hpp:20